@@ -2,13 +2,15 @@
 import logging
 import numpy as np
 from numpy.polynomial.polynomial import Polynomial
-from scipy.ndimage.filters import median_filter
-import scipy.fft
+from scipy.ndimage import median_filter
+import scipy.fft  # pylint: disable=E0611
 from ..utils import previouspow2
 from ..misc import fourier_filters
 from ..resources.logger import LoggerOrPrint
+
 try:
     import matplotlib.pyplot as plt
+
     __have_matplotlib__ = True
 except ImportError:
     logging.getLogger(__name__).warning("Matplotlib not available. Plotting disabled")
@@ -17,21 +19,31 @@ except ImportError:
 
 try:
     from tqdm import tqdm
+
     def progress_bar(x, verbose=True):
         if verbose:
             return tqdm(x)
         else:
             return x
+
 except ImportError:
+
     def progress_bar(x, verbose=True):
         return x
 
+
 local_fftn = scipy.fft.rfftn
 local_ifftn = scipy.fft.irfftn
 
+
 class AlignmentBase:
     def __init__(
-        self, vert_fft_width=False, horz_fft_width=False, verbose=False, logger=None, data_type=np.float32,
+        self,
+        vert_fft_width=False,
+        horz_fft_width=False,
+        verbose=False,
+        logger=None,
+        data_type=np.float32,
     ):
         """
         Alignment basic functions.
@@ -74,7 +86,8 @@ class AlignmentBase:
         shape_pos = np.squeeze(img_pos).shape
         if not len(shape_stack) == 3:
             raise ValueError(
-                "A stack of 2-dimensional images is required. Shape of stack: %s" % (" ".join(("%d" % x for x in shape_stack)))
+                "A stack of 2-dimensional images is required. Shape of stack: %s"
+                % (" ".join(("%d" % x for x in shape_stack)))
             )
         if not len(shape_pos) == 1:
             raise ValueError(
@@ -85,7 +98,10 @@ class AlignmentBase:
             raise ValueError(
                 "The same number of images and positions is required."
                 + " Shape of stack: %s, shape of positions variable: %s"
-                % (" ".join(("%d" % x for x in shape_stack)), " ".join(("%d" % x for x in shape_pos)),)
+                % (
+                    " ".join(("%d" % x for x in shape_stack)),
+                    " ".join(("%d" % x for x in shape_pos)),
+                )
             )
 
     @staticmethod
@@ -93,13 +109,20 @@ class AlignmentBase:
         shape_1 = np.squeeze(img_1).shape
         shape_2 = np.squeeze(img_2).shape
         if not len(shape_1) == 2:
-            raise ValueError("Images need to be 2-dimensional. Shape of image #1: %s" % (" ".join(("%d" % x for x in shape_1))))
+            raise ValueError(
+                "Images need to be 2-dimensional. Shape of image #1: %s" % (" ".join(("%d" % x for x in shape_1)))
+            )
         if not len(shape_2) == 2:
-            raise ValueError("Images need to be 2-dimensional. Shape of image #2: %s" % (" ".join(("%d" % x for x in shape_2))))
+            raise ValueError(
+                "Images need to be 2-dimensional. Shape of image #2: %s" % (" ".join(("%d" % x for x in shape_2)))
+            )
         if not np.all(shape_1 == shape_2):
             raise ValueError(
                 "Images need to be of the same shape. Shape of image #1: %s, image #2: %s"
-                % (" ".join(("%d" % x for x in shape_1)), " ".join(("%d" % x for x in shape_2)),)
+                % (
+                    " ".join(("%d" % x for x in shape_1)),
+                    " ".join(("%d" % x for x in shape_2)),
+                )
             )
 
     @staticmethod
@@ -152,7 +175,7 @@ class AlignmentBase:
         fy, fx = np.meshgrid(fy, fx, indexing="ij")
         fy = fy.flatten()
         fx = fx.flatten()
-        coords = np.array([np.ones(f_vals.size), fy, fx, fy * fx, fy ** 2, fx ** 2])
+        coords = np.array([np.ones(f_vals.size), fy, fx, fy * fx, fy**2, fx**2])
 
         coeffs = np.linalg.lstsq(coords.T, f_vals.flatten(), rcond=None)[0]
 
@@ -168,7 +191,12 @@ class AlignmentBase:
         if np.any(vertex_yx < vertex_min_yx) or np.any(vertex_yx > vertex_max_yx):
             raise ValueError(
                 "Fitted (y: {}, x: {}) positions are outside the input margins y: [{}, {}], and x: [{}, {}]".format(
-                    vertex_yx[0], vertex_yx[1], vertex_min_yx[0], vertex_max_yx[0], vertex_min_yx[1], vertex_max_yx[1],
+                    vertex_yx[0],
+                    vertex_yx[1],
+                    vertex_min_yx[0],
+                    vertex_max_yx[0],
+                    vertex_min_yx[1],
+                    vertex_max_yx[1],
                 )
             )
         return vertex_yx
@@ -221,12 +249,12 @@ class AlignmentBase:
             poly = Polynomial.fit(fx, f_vals, deg=2)
             coeffs = poly.convert().coef
         else:
-            coords = np.array([np.ones(num_vals), fx, fx ** 2])
+            coords = np.array([np.ones(num_vals), fx, fx**2])
             coeffs = np.linalg.lstsq(coords.T, f_vals, rcond=None)[0]
 
         # For a 1D parabola `f(x) = c + bx + ax^2`, the vertex position is:
         # x_v = -b / 2a.
-        vertex_x = -coeffs[1, :] / (2 * coeffs[2, :])
+        vertex_x = (-coeffs[1, :] / (2 * coeffs[2, :]))[0]
 
         vertex_min_x = np.min(fx)
         vertex_max_x = np.max(fx)
@@ -234,10 +262,15 @@ class AlignmentBase:
         upper_bound_ok = vertex_x < vertex_max_x
         if not np.all(lower_bound_ok * upper_bound_ok):
             if len(f_vals.shape) == 1:
-                message = "Fitted position {} is outide the input margins [{}, {}]".format(vertex_x, vertex_min_x, vertex_max_x)
+                message = "Fitted position {} is outide the input margins [{}, {}]".format(
+                    vertex_x, vertex_min_x, vertex_max_x
+                )
             else:
                 message = "Fitted positions outide the input margins [{}, {}]: {} below and {} above".format(
-                    vertex_min_x, vertex_max_x, np.sum(1 - lower_bound_ok), np.sum(1 - upper_bound_ok),
+                    vertex_min_x,
+                    vertex_max_x,
+                    np.sum(1 - lower_bound_ok),
+                    np.sum(1 - upper_bound_ok),
                 )
             raise ValueError(message)
         if return_vertex_val:
@@ -358,7 +391,13 @@ class AlignmentBase:
         return roi_yxhw
 
     def _prepare_image(
-        self, img, invalid_val=1e-5, roi_yxhw=None, median_filt_shape=None, low_pass=None, high_pass=None,
+        self,
+        img,
+        invalid_val=1e-5,
+        roi_yxhw=None,
+        median_filt_shape=None,
+        low_pass=None,
+        high_pass=None,
     ):
         """
         Prepare and returns  a cropped  and filtered image, or array of filtered images if the input is an  array of images.
@@ -386,7 +425,9 @@ class AlignmentBase:
 
         if roi_yxhw is not None:
             img = img[
-                ..., roi_yxhw[0] : roi_yxhw[0] + roi_yxhw[2], roi_yxhw[1] : roi_yxhw[1] + roi_yxhw[3],
+                ...,
+                roi_yxhw[0] : roi_yxhw[0] + roi_yxhw[2],
+                roi_yxhw[1] : roi_yxhw[1] + roi_yxhw[3],
             ]
 
         img = img.copy()
@@ -410,7 +451,10 @@ class AlignmentBase:
             # expanding filter shape with ones, to cover the stack of images
             # but disabling inter-image filtering
             median_filt_shape = np.concatenate(
-                (np.ones((len(img_shape) - len(median_filt_shape),), dtype=np.intp), median_filt_shape,)
+                (
+                    np.ones((len(img_shape) - len(median_filt_shape),), dtype=np.intp),
+                    median_filt_shape,
+                )
             )
             img = median_filter(img, size=median_filt_shape)
         return img
@@ -478,10 +522,7 @@ class AlignmentBase:
         return cc
 
     def _add_plot_window(self, fig, ax=None):
-        self._plot_windows[fig.number] = {
-            "figure": fig,
-            "axes": ax
-        }
+        self._plot_windows[fig.number] = {"figure": fig, "axes": ax}
 
     def close_plot_window(self, n, errors="raise"):
         """
@@ -503,7 +544,7 @@ class AlignmentBase:
             elif errors == "log":
                 self.logger.error(msg)
         fig_ax = self._plot_windows.pop(n)
-        plt.close(fig_ax["figure"].number) # would also work with the object itself
+        plt.close(fig_ax["figure"].number)  # would also work with the object itself
 
     def close_last_plot_windows(self, n=1):
         """
